@@ -25,6 +25,7 @@
 #include "sourcesmodel.h"
 #include "preview.h"
 #include "draghelper.h"
+#include "mousehelper.h"
 
 #include <QtQml/qqml.h>
 
@@ -37,5 +38,9 @@ void QmlPlugins::registerTypes(const char *uri)
     qmlRegisterType<Milou::SourcesModel> (uri, 0, 1, "SourcesModel");
     qmlRegisterType<Milou::Preview> (uri, 0, 1, "Preview");
     qmlRegisterType<Milou::DragHelper> (uri, 0, 2, "DragHelper");
+    qmlRegisterSingletonType<Milou::MouseHelper> (uri, 0, 1, "MouseHelper",
+                                                  [](QQmlEngine*, QJSEngine*) -> QObject* {
+        return new Milou::MouseHelper();
+    });
 }
 
